@@ -1691,7 +1691,7 @@ class CancelMoves(Wizard):
             to_reconcile = defaultdict(list)
             for line in move.lines + cancel_move.lines:
                 if line.account.reconcile:
-                    to_reconcile[line.account].append(line)
+                    to_reconcile[(line.account, line.party)].append(line)
             for lines in to_reconcile.itervalues():
                 Line.reconcile(lines)
         return 'end'
